summary refs log tree commit diff
path: root/pkgs/tools/typesetting/tex/texlive-new
diff options
context:
space:
mode:
authorNikolay Amiantov <ab@fmap.me>2016-02-02 16:56:05 +0300
committerRaymond Gauthier <jraygauthier@gmail.com>2016-04-14 01:14:53 -0400
commit0435ac88948e53b90b6dad583364a8d040473dd6 (patch)
tree2d7614dbc3a959b3b659fe171bb18e8323f1ef48 /pkgs/tools/typesetting/tex/texlive-new
parent3f9cfba02c64a2d98b34c595f551a7eb5c847647 (diff)
downloadnixpkgs-0435ac88948e53b90b6dad583364a8d040473dd6.tar
nixpkgs-0435ac88948e53b90b6dad583364a8d040473dd6.tar.gz
nixpkgs-0435ac88948e53b90b6dad583364a8d040473dd6.tar.bz2
nixpkgs-0435ac88948e53b90b6dad583364a8d040473dd6.tar.lz
nixpkgs-0435ac88948e53b90b6dad583364a8d040473dd6.tar.xz
nixpkgs-0435ac88948e53b90b6dad583364a8d040473dd6.tar.zst
nixpkgs-0435ac88948e53b90b6dad583364a8d040473dd6.zip
texlive.combine: patch paths into texmf.cnf
...instead of environment variables. Close #12768.

(cherry picked from commit acf664814e37c54a7c12b1d065354cab15382793)
Diffstat (limited to 'pkgs/tools/typesetting/tex/texlive-new')
-rw-r--r--pkgs/tools/typesetting/tex/texlive-new/combine.nix21
1 files changed, 10 insertions, 11 deletions
diff --git a/pkgs/tools/typesetting/tex/texlive-new/combine.nix b/pkgs/tools/typesetting/tex/texlive-new/combine.nix
index e69c6ec425c..0619a3cc26c 100644
--- a/pkgs/tools/typesetting/tex/texlive-new/combine.nix
+++ b/pkgs/tools/typesetting/tex/texlive-new/combine.nix
@@ -60,21 +60,24 @@ in buildEnv {
     +
   ''
     export PATH="$out/bin:$out/share/texmf/scripts/texlive:${perl}/bin:$PATH"
-    export TEXMFCNF="$out/share/texmf/web2c"
-    export TEXMFDIST="$out/share/texmf"
-    export TEXMFSYSCONFIG="$out/share/texmf-config"
-    export TEXMFSYSVAR="$out/share/texmf-var"
     export PERL5LIB="$out/share/texmf/scripts/texlive"
   '' +
     # patch texmf-dist -> texmf to be sure
     # TODO: cleanup the search paths incl. SELFAUTOLOC, and perhaps do lua actions?
     # tried inspiration from install-tl, sub do_texmf_cnf
   ''
     (
       cd ./share/texmf/web2c/
       local cnfOrig="$(realpath ./texmf.cnf)"
       rm ./texmf.cnf
-      cat "$cnfOrig" | sed 's/texmf-dist/texmf/g' > ./texmf.cnf
+      sed \
+        -e 's,texmf-dist,texmf,g' \
+        -e 's,texmf-local,texmf,g' \
+        -e "s,\$SELFAUTOLOC,$out,g" \
+        -e "s,\$SELFAUTODIR,$out/share,g" \
+        -e "s,\$SELFAUTOPARENT,$out/share,g" \
+        -e "s,\$SELFAUTOGRANDPARENT,$out/share,g" \
+        "$cnfOrig" > ./texmf.cnf
 
       rm updmap.cfg
     )
@@ -112,10 +115,6 @@ in buildEnv {
       rm "$link"
       makeWrapper "$target" "$link" \
         --prefix PATH : "$out/bin:${perl}/bin" \
-        --set TEXMFCNF "$out/share/texmf/web2c" \
-        --set TEXMFDIST "$out/share/texmf" \
-        --set TEXMFSYSCONFIG "$out/share/texmf-config" \
-        --set TEXMFSYSVAR "$out/share/texmf-var" \
         --prefix PERL5LIB : "$out/share/texmf/scripts/texlive"
 
       # avoid using non-nix shebang in $target by calling interpreter
@@ -60,21 +60,24 @@ in buildEnv {
     export PERL5LIB="$out/share/texmf/scripts/texlive"
   '' +
-    # patch texmf-dist -> texmf to be sure
-    # TODO: cleanup the search paths incl. SELFAUTOLOC, and perhaps do lua actions?
+    # patch texmf-{dist,local} -> texmf to be sure
+    # TODO: perhaps do lua actions?
     # tried inspiration from install-tl, sub do_texmf_cnf
   ''